leiningen.jank


build-dependencies->dependenciesclj

(build-dependencies->dependencies {:keys [build-dependencies] :as project})

Compute regular :dependencies coordinates from the jank-specific :build-dependencies coordinates.

We simply add a :scope 'jank-build' to the end of the coordinate, which designates it as a build-time dependency.

Compute regular :dependencies coordinates from the jank-specific
:build-dependencies coordinates.

We simply add a :scope 'jank-build' to the end of the coordinate, which
designates it as a build-time dependency.
raw docstring

check-health!clj

(check-health! project & args)

Perform a health check on your jank install.

Perform a health check on your jank install.
raw docstring

compile!clj

(compile! project & args)

Compile your project to an executable.

Compile your project to an executable.
raw docstring

compile-module!clj

(compile-module! project & args)

Compile a single module and its dependencies to object files.

Compile a single module and its dependencies to object files.
raw docstring

deep-mergeclj

(deep-merge & maps)

deep-merge*clj

(deep-merge* & maps)

deep-merge-metadataclj

(deep-merge-metadata & maps)

Deep merges metadata from multiple maps. Returns merged metadata or nil.

Deep merges metadata from multiple maps. Returns merged metadata or nil.
raw docstring

default-projectclj

(default-project project)

jankclj

(jank project subcmd & args)

Compile, run, test and repl into jank.

Compile, run, test and repl into jank.
raw docstring

middlewareclj

(middleware project)

Inject jank project details into your current project.

Inject jank project details into your current project.
raw docstring

native-buildclj

(native-build project opts)

(print-help! & _args)

Show this help message.

Show this help message.
raw docstring

process-jank-argsclj

(process-jank-args args)

process-task-argsclj

(process-task-args project args)

Extract task-specific args from the list and return the parsed options and the leftover arguments.

Extract task-specific args from the list and return the parsed options and
the leftover arguments.
raw docstring

repl!clj

(repl! project & args)

Start a terminal REPL in your :main ns.

Start a terminal REPL in your :main ns.
raw docstring

run!clj

(run! project & args)

Run your project, starting at the main entrypoint.

Run your project, starting at the main entrypoint.
raw docstring

subtask-kw->varclj


verbatim->filespecsclj

(verbatim->filespecs {:keys [root verbatim-paths] :as project})

Specify filespecs to copy files or directories in the :verbatim-paths project key into the output archive.

These paths are copied exactly, whereas the standard keys like :source-paths strip the path prefix such that the entries appear directly on the classpath when the jar is loaded.

Specify filespecs to copy files or directories in the :verbatim-paths project
key into the output archive.

These paths are copied exactly, whereas the standard keys like :source-paths
strip the path prefix such that the entries appear directly on the classpath
when the jar is loaded.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries