leiningen.jank.sandbox.bwrap


bwrapclj

(bwrap cmds)

Build a bwrap command with the given options, returning the command.

Valid options are:

  • [:ro-bind src dst]
  • [:bind src dst]
  • [:tmpfs dir]
  • [:chdir dir]
  • [:net enabled?]
Build a `bwrap` command with the given options, returning the command.

Valid options are:
  - [:ro-bind src dst]
  - [:bind src dst]
  - [:tmpfs dir]
  - [:chdir dir]
  - [:net enabled?]
raw docstring

standard-bindsclj

Directories which are required for typical program execution.

Some of these may not exist on all systems.

Directories which are required for typical program execution.

Some of these may not exist on all systems.
raw docstring

which-bwrapclj

(which-bwrap)

Find the bwrap executable on the path, or nil if it cannot be found.

Find the `bwrap` executable on the path, or nil if it cannot be found.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries