Clojure only.

leiningen.jank.sandbox.core


processclj

(process enable? sandbox-opts cmd sh-opts)

Pass cmd and sh-opts to babashka.process/process running inside of a sandboxed container specified by sandbox-opts.

Setting the enable? flag to false allows sandboxing to be skipped entirely and the command will be run as a standard shell process.

Pass `cmd` and `sh-opts` to `babashka.process/process` running inside of a
sandboxed container specified by `sandbox-opts`.

Setting the `enable?` flag to false allows sandboxing to be skipped entirely
and the command will be run as a standard shell process.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries