leiningen.jank.test


form-for-suppressing-unselected-testsclj

A function that figures out which vars need to be suppressed based on the given selectors, moves their :test metadata to :leiningen/skipped-test (so that clojure.test won't think they are tests), runs the given function, and then sets the metadata back.

A function that figures out which vars need to be suppressed based on the
given selectors, moves their :test metadata to :leiningen/skipped-test (so
that clojure.test won't think they are tests), runs the given function, and
then sets the metadata back.
raw docstring

read-argsclj

(read-args args project)

test!clj

(test! project & args)

cljdoc builds & hosts documentation for Clojure/Script libraries