(build-dependencies->dependencies {:keys [build-dependencies] :as project})Compute regular :dependencies coordinates from the jank-specific :build-dependencies coordinates.
We simply add a :scope 'jank-build' to the end of the coordinate, which designates it as a build-time dependency.
Compute regular :dependencies coordinates from the jank-specific :build-dependencies coordinates. We simply add a :scope 'jank-build' to the end of the coordinate, which designates it as a build-time dependency.
(check-health! project & args)Perform a health check on your jank install.
Perform a health check on your jank install.
(compile! project & args)Compile your project to an executable.
Compile your project to an executable.
(compile-module! project & args)Compile a single module and its dependencies to object files.
Compile a single module and its dependencies to object files.
(deep-merge & maps)(deep-merge* & maps)(deep-merge-metadata & maps)Deep merges metadata from multiple maps. Returns merged metadata or nil.
Deep merges metadata from multiple maps. Returns merged metadata or nil.
(default-project project)(jank project subcmd & args)Compile, run, test and repl into jank.
Compile, run, test and repl into jank.
(middleware project)Inject jank project details into your current project.
Inject jank project details into your current project.
(native-build project opts)(process-jank-args args)(process-task-args project args)Extract task-specific args from the list and return the parsed options and the leftover arguments.
Extract task-specific args from the list and return the parsed options and the leftover arguments.
(repl! project & args)Start a terminal REPL in your :main ns.
Start a terminal REPL in your :main ns.
(run! project & args)Run your project, starting at the main entrypoint.
Run your project, starting at the main entrypoint.
(verbatim->filespecs {:keys [root verbatim-paths] :as project})Specify filespecs to copy files or directories in the :verbatim-paths project key into the output archive.
These paths are copied exactly, whereas the standard keys like :source-paths strip the path prefix such that the entries appear directly on the classpath when the jar is loaded.
Specify filespecs to copy files or directories in the :verbatim-paths project key into the output archive. These paths are copied exactly, whereas the standard keys like :source-paths strip the path prefix such that the entries appear directly on the classpath when the jar is loaded.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |