leiningen.jank


check-health!clj

(check-health! project & args)

Perform a health check on your jank install.

Perform a health check on your jank install.
raw docstring

compile!clj

(compile! project & args)

Compile your project to an executable.

Compile your project to an executable.
raw docstring

compile-module!clj

(compile-module! project & args)

Compile a single module and its dependencies to object files.

Compile a single module and its dependencies to object files.
raw docstring

deep-mergeclj

(deep-merge & maps)

deep-merge*clj

(deep-merge* & maps)

deep-merge-metadataclj

(deep-merge-metadata & maps)

Deep merges metadata from multiple maps. Returns merged metadata or nil.

Deep merges metadata from multiple maps. Returns merged metadata or nil.
raw docstring

default-projectclj


jankclj

(jank project subcmd & args)

Compile, run, test and repl into jank.

Compile, run, test and repl into jank.
raw docstring

middlewareclj

(middleware project)

Inject jank project details into your current project.

Inject jank project details into your current project.
raw docstring

(print-help! & _args)

Show this help message.

Show this help message.
raw docstring

process-argsclj

(process-args args)

repl!clj

(repl! project & args)

Start a terminal REPL in your :main ns.

Start a terminal REPL in your :main ns.
raw docstring

run!clj

(run! project & args)

Run your project, starting at the main entrypoint.

Run your project, starting at the main entrypoint.
raw docstring

subtask-kw->varclj

cljdoc builds & hosts documentation for Clojure/Script libraries