(dependency-files tree)For a dependency tree, resolve all of the artifact paths, returned as a sequence of string paths.
NOTE: The coordinates must be augmented with aether metadata returned by e.g.
resolve-tree.
For a dependency tree, resolve all of the artifact paths, returned as a sequence of string paths. NOTE: The coordinates must be augmented with aether metadata returned by e.g. `resolve-tree`.
(dependency-hierarchy project dep)Resolve the full dependency tree from a given root coordinate. All tree entries are annotated with aether metadata.
This is like aether/dependency-hierarchy, but it does not perform
deduplication on the tree. If the same dependency in two or more subtrees
(even the same version), they will remain in the tree returned here.
Resolve the full dependency tree from a given root coordinate. All tree entries are annotated with aether metadata. This is like `aether/dependency-hierarchy`, but it does not perform deduplication on the tree. If the same dependency in two or more subtrees (even the same version), they will remain in the tree returned here.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |