A function that figures out which vars need to be suppressed based on the given selectors, moves their :test metadata to :leiningen/skipped-test (so that clojure.test won't think they are tests), runs the given function, and then sets the metadata back.
A function that figures out which vars need to be suppressed based on the given selectors, moves their :test metadata to :leiningen/skipped-test (so that clojure.test won't think they are tests), runs the given function, and then sets the metadata back.
(read-args args project)(test! project & args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |